==========
pycroscopy
==========

.. image:: https://travis-ci.org/pycroscopy/pycroscopy.svg?branch=master
    :target: https://travis-ci.org/pycroscopy/pycroscopy

pycroscopy is a `python <http://www.python.org/>`_ package for image processing and scientific analysis of imaging modalities such as multi-frequency scanning probe microscopy, scanning tunneling spectroscopy, x-ray diffraction microscopy, and transmission electron microscopy. pycroscopy uses a data-centric model wherein the raw data collected from the microscope, results from analysis and processing routines are all written to standardized hierarchical data format (HDF5) files for traceability, reproducibility, and provenance.

Please visit our `homepage <https://pycroscopy.github.io/pycroscopy/about.html>`_ for more information and installation instructions.
